@@ -170,6 +170,12 @@ FAILEDOPERATION_UPDATEFUNCTIONCODE = 'FailedOperation.UpdateFunctionCode'
 # UpdateFunctionConfiguration操作失败。
 FAILEDOPERATION_UPDATEFUNCTIONCONFIGURATION = 'FailedOperation.UpdateFunctionConfiguration'
 
+# 更新状态操作失败。
+FAILEDOPERATION_UPDATESTATUS = 'FailedOperation.UpdateStatus'
+
+# 与原状态一致，无需更改。
+FAILEDOPERATION_UPDATETRIGGERSTATUS = 'FailedOperation.UpdateTriggerStatus'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -578,6 +584,9 @@ LIMITEXCEEDED_ALIAS = 'LimitExceeded.Alias'
 # Cdn使用超过最大限制。
 LIMITEXCEEDED_CDN = 'LimitExceeded.Cdn'
 
+# 用户开启镜像加速函数版本超限。
+LIMITEXCEEDED_CONTAINERIMAGEACCELERATE = 'LimitExceeded.ContainerImageAccelerate'
+
 # 用户开启镜像加速函数版本超限。
 LIMITEXCEEDED_CONTAINERIMAGEACCELERATEQUOTA = 'LimitExceeded.ContainerImageAccelerateQuota'
 
@@ -605,6 +614,9 @@ LIMITEXCEEDED_FUNCTIONTOTALPROVISIONEDCONCURRENCYNUM = 'LimitExceeded.FunctionTo
 # InitTimeout达到限制，可提交工单申请提升限制：https://tencentcs.com/7Fixwt63。
 LIMITEXCEEDED_INITTIMEOUT = 'LimitExceeded.InitTimeout'
 
+# 内网固定IP个数超限。
+LIMITEXCEEDED_INTRAIP = 'LimitExceeded.IntraIp'
+
 # layer版本数量超出最大限制。
 LIMITEXCEEDED_LAYERVERSIONS = 'LimitExceeded.LayerVersions'
 
@@ -707,6 +719,9 @@ RESOURCENOTFOUND_ALIAS = 'ResourceNotFound.Alias'
 # 未找到指定的AsyncEvent，请创建后再试。
 RESOURCENOTFOUND_ASYNCEVENT = 'ResourceNotFound.AsyncEvent'
 
+# 函数需要关联的标签Key不存在。
+RESOURCENOTFOUND_ATTACHEDTAGKEYNOTFOUND = 'ResourceNotFound.AttachedTagKeyNotFound'
+
 # Cdn不存在。
 RESOURCENOTFOUND_CDN = 'ResourceNotFound.Cdn'
 
@@ -824,6 +839,9 @@ UNAUTHORIZEDOPERATION_TEMPCOSAPPID = 'UnauthorizedOperation.TempCosAppid'
 # 无法进行此操作。
 UNAUTHORIZEDOPERATION_UPDATEFUNCTIONCODE = 'UnauthorizedOperation.UpdateFunctionCode'
 
+# 没有权限。
+UNAUTHORIZEDOPERATION_UPDATETRIGGERSTATUS = 'UnauthorizedOperation.UpdateTriggerStatus'
+
 # 操作不支持。
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 
